@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,18 +30,27 @@
 
 #include "templatetype.h"
 
-class IndexingType: public TemplateType<IndexingType>{
+class __libcore IndexingType: public TemplateType<IndexingType>{
+	private:
+		static const QStringList type_names;
+
 	public:
 		static constexpr unsigned Btree = 1,
-		Gist = 2,
-		Hash = 3,
+		Brin = 2,
+		Gist = 3,
 		Gin = 4,
-		Spgist = 5,
-		Brin = 6;
+		Hash = 5,
+		Spgist = 6;
 
 		IndexingType(const QString &type_name);
 		IndexingType(unsigned type_id);
 		IndexingType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
