@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,17 +23,13 @@
 #include "attributes.h"
 #include "../baseobject.h"
 
-std::vector<UserTypeConfig> PgSqlType::user_types;
-
-QStringList PgSqlType::type_names =
-{
+const QStringList PgSqlType::type_names {
 	"", // Reserved for Class::Null
 
 	//Types used by the class PgSQLType
 	//offsets 1 to 63
 	//Note: the type char is different from "char" (with quotes)
 	//Reference: http://www.postgresql.org/docs/9.2/static/datatype-character.html
-
 	"smallint", "integer", "bigint", "decimal", "numeric",
 	"real", "double precision", "float", "serial", "bigserial", "money",
 	"character varying", "varchar", "character",  "char", "\"char\"",
@@ -81,6 +80,8 @@ QStringList PgSqlType::type_names =
 	"pg_ddl_command", "void", "unknown"
 };
 
+std::vector<UserTypeConfig> PgSqlType::user_types;
+
 PgSqlType::PgSqlType()
 {
 	type_idx = type_names.indexOf("smallint");
@@ -536,7 +537,7 @@ void PgSqlType::setSpatialType(SpatialType spat_type)
 
 void PgSqlType::setWithTimezone(bool with_tz)
 {
-	this->with_timezone = with_tz && !isTimezoneType();
+	this->with_timezone = with_tz && acceptsTimezone();
 }
 
 unsigned PgSqlType::setUserType(unsigned type_id)
@@ -576,7 +577,6 @@ void PgSqlType::addUserType(const QString &type_name, BaseObject *ptype, UserTyp
 
 		cfg.name = type_name;
 		cfg.ptype = ptype;
-		//cfg.pmodel=pmodel;
 		cfg.pmodel = ptype->getDatabase();
 		cfg.type_conf = type_conf;
 		PgSqlType::user_types.push_back(cfg);
@@ -610,22 +610,16 @@ void PgSqlType::removeUserType(const QString &type_name, BaseObject *ptype)
 
 void PgSqlType::renameUserType(const QString &type_name, BaseObject *ptype, const QString &new_name)
 {
-	if(PgSqlType::user_types.size() > 0 &&
-			!type_name.isEmpty() && ptype && type_name!=new_name)
+	if(PgSqlType::user_types.empty() ||
+		 type_name.isEmpty() || !ptype || type_name == new_name)
+		return;
+
+	for(auto &tp : user_types)
 	{
-		std::vector<UserTypeConfig>::iterator itr, itr_end;
-
-		itr=PgSqlType::user_types.begin();
-		itr_end=PgSqlType::user_types.end();
-
-		while(itr!=itr_end)
+		if(!tp.invalidated && tp.name == type_name && tp.ptype == ptype)
 		{
-			if(!itr->invalidated && itr->name==type_name && itr->ptype==ptype)
-			{
-				itr->name=new_name;
-				break;
-			}
-			itr++;
+			tp.name = new_name;
+			break;
 		}
 	}
 }
@@ -838,8 +832,8 @@ bool PgSqlType::isTimezoneType()
 	QString curr_type = getTypeName(false);
 
 	return (!isUserType() &&
-					(curr_type=="timetz" || curr_type == "timestamptz" ||
-					 curr_type=="time with time zone" || curr_type=="timestamp with time zone"));
+					(curr_type == "timetz" || curr_type == "timestamptz" ||
+					 curr_type == "time with time zone" || curr_type == "timestamp with time zone"));
 }
 
 bool PgSqlType::isNumericType()
@@ -978,6 +972,13 @@ bool PgSqlType::acceptsPrecision()
 					(!isUserType() && type_names[this->type_idx]!="date" && isDateTimeType()));
 }
 
+bool PgSqlType::acceptsTimezone()
+{
+	return !isUserType() &&
+				 (type_names[this->type_idx] == "time"  ||
+					type_names[this->type_idx] == "timestamp");
+}
+
 void PgSqlType::reset(bool all_attrs)
 {
 	setIntervalType(IntervalType::Null);
