@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,11 +21,8 @@
 
 #include "providertype.h"
 
-template<>
-QStringList ProviderType::TemplateType<ProviderType>::type_names =
-{
-	"", // Reserved for BaseType::null
-
+const QStringList ProviderType::type_names {
+	"", // Reserved for Class::Null
 	"libc",
 	"icu"
 };
@@ -41,3 +41,23 @@ ProviderType::ProviderType()
 {
 	type_idx = LibC;
 }
+
+QStringList ProviderType::getTypes()
+{
+	return TemplateType<ProviderType>::getTypes(type_names);
+}
+
+unsigned ProviderType::setType(unsigned type_id)
+{
+	return TemplateType<ProviderType>::setType(type_id, type_names);
+}
+
+unsigned ProviderType::setType(const QString &type_name)
+{
+	return TemplateType<ProviderType>::setType(type_name, type_names);
+}
+
+QString ProviderType::getTypeName(unsigned type_id)
+{
+	return TemplateType<ProviderType>::getTypeName(type_id, type_names);
+}
