@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,14 +26,6 @@ Procedure::Procedure() : BaseFunction()
 	obj_type = ObjectType::Procedure;
 }
 
-void Procedure::addParameter(Parameter param)
-{
-	if(param.isOut() && !param.isIn())
-		throw Exception(ErrorCode::InvProcedureParamOutMode, __PRETTY_FUNCTION__, __FILE__, __LINE__);
-
-	BaseFunction::addParameter(param);
-}
-
 QString Procedure::getSourceCode(SchemaParser::CodeType def_type, bool)
 {
 	QString code_def = getCachedCode(def_type, false);
@@ -58,13 +53,6 @@ QString Procedure::getAlterCode(BaseObject *object)
 		attribs_map attribs;
 		attribs = BaseFunction::getAlterCodeAttributes(proc);
 
-		if(this->func_source.simplified() != proc->func_source.simplified() ||
-			 this->library != proc->library || this->symbol != proc->symbol)
-		{
-			attribs[Attributes::Definition] = proc->getSourceCode(SchemaParser::SqlCode);
-			attribs[Attributes::Definition].replace(QString("CREATE PROCEDURE").arg(this->getSQLName()), QString("CREATE OR REPLACE PROCEDURE"));
-		}
-
 		copyAttributes(attribs);
 		return BaseObject::getAlterCode(this->getSchemaName(), attributes, false, true);
 	}
@@ -73,3 +61,8 @@ QString Procedure::getAlterCode(BaseObject *object)
 		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
+
+void Procedure::updateDependencies()
+{
+	BaseFunction::updateDependencies({});
+}
