@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,8 +32,8 @@ also generates the SQL code definition to represente the table link on PostgreSQ
 
 #include "baserelationship.h"
 #include "table.h"
-#include "textbox.h"
 #include "pgsqltypes/actiontype.h"
+#include <stack>
 
 /*
 ### Relationship implementation rules ###
@@ -126,7 +129,8 @@ class __libcore Relationship: public BaseRelationship {
 			DstFkPattern,
 			PkPattern,
 			UqPattern,
-			PkColPattern
+			PkColPattern,
+			FkIdxPattern
 		};
 
 	private:
@@ -173,6 +177,12 @@ class __libcore Relationship: public BaseRelationship {
 		//! \brief Relationship constraint (used as constraints on the receiver table)
 		std::vector<TableObject *> rel_constraints;
 
+		//! \brief The index that is created on foreign key columns (only for 1-1, 1-n and n-n relationships)
+		Index *fk_index;
+
+		//! \brief The indexing type (access method) that is used by the FK index (only for 1-1, 1-n and n-n relationships)
+		IndexingType fk_idx_type;
+
 		//! \brief Foreign key that represents the 1-n relationship
 		Constraint *fk_rel1n,
 
@@ -224,6 +234,23 @@ class __libcore Relationship: public BaseRelationship {
 		//! \brief The partition bounding expression
 		QString part_bounding_expr;
 
+		std::stack<Column *> cols_stack;
+
+		std::stack<Constraint *> constrs_stack;
+
+		std::stack<Index *> indexes_stack;
+
+		/*! \brief This method creates via "new" operator the object of the type Class, or,
+		 * return an object from the stack of discarded objects if available for reused.
+		 * Valid object types are Column, Constraint and Index. Returns null when Class is
+		 * any other db object class */
+		template<class Class>
+		Class *createObject();
+
+		/*! \brief This method stores the object in a stack of discarded objects instead of using delete operator
+		 *  to free memory so the object can be resused the next time createObject() is called */
+		void discardObject(TableObject *object);
+
 		//! \brief Indicates if the column exists on the referenced column list
 		bool isColumnExists(Column *column);
 
@@ -253,10 +280,14 @@ class __libcore Relationship: public BaseRelationship {
 		 to the receiver table. Must be specified the actions ON DELETE and UPDATE. */
 		void addForeignKey(PhysicalTable *ref_tab, PhysicalTable *recv_tab, ActionType del_act, ActionType upd_act);
 
-		/*! \brief Creates the unique key that represents the 1-1 relationship e adds it to
+		/*! \brief Creates the unique key that represents the 1-1 relationship and adds it to
 		 the receiver table */
 		void addUniqueKey(PhysicalTable *recv_tab);
 
+		/*! \brief Creates the index on the foreign key index hat represents the 1-* and n-n relationships
+		 * and adds it to the receiver table */
+		void addForeignKeyIndex(PhysicalTable *recv_tab);
+
 		//! \brief Adds the relationship attributes (columns) into receiver table
 		void addAttributes(PhysicalTable *recv_tab);
 
@@ -311,26 +342,25 @@ class __libcore Relationship: public BaseRelationship {
 		 unique key used in 1-1 relationships */
 		std::vector<Constraint *> getGeneratedConstraints();
 
-		virtual void configureSearchAttributes();
+		//! \brief Returns the index generated by the 1-* and n-n relationships
+		Index *getGeneratedIndex();
+
+		virtual void configureSearchAttributes() override;
 
 	public:
 		//! \brief String used as the name suffix separator. Default '_'
-		static const QString SuffixSeparator,
-		SrcTabToken, //{st}
-		DstTabToken, //{dt}
-		GenTabToken, //{gt}
-		SrcColToken; //{sc}
+		static const QString	SuffixSeparator,
+		SrcTabToken,
+		DstTabToken,
+		GenTabToken,
+		SrcColToken;
 
 		Relationship(Relationship *rel);
 
 		Relationship(BaseRelationship::RelType rel_type,
-					 PhysicalTable *src_tab, PhysicalTable *dst_tab,
-					 bool src_mdtry=false, bool dst_mdtry=false,
-					 bool identifier=false, bool deferrable=false,
-					 DeferralType deferral_type=DeferralType::Immediate,
-					 ActionType fk_del_act=ActionType::Null,
-					 ActionType fk_upd_act=ActionType::Null,
-					 CopyOptions copy_op = CopyOptions());
+								 PhysicalTable *src_tab, PhysicalTable *dst_tab,
+								 bool src_mdtry = false, bool dst_mdtry = false,
+								 bool identifier = false);
 
 		//! \brief  Connects the relationship making the configuration according to its type
 		void connectRelationship();
@@ -388,11 +418,17 @@ class __libcore Relationship: public BaseRelationship {
 
 		/*! \brief Defines the type of action for generated foreign keys (ON DELETE and ON UPDATE)
 		 User must use Constraint::[DELETE_ACTION|UPDATE_ACTION] (only for 1-1, 1-n relationships) */
-		void setActionType(ActionType act_type, unsigned act_id);
+		void setActionType(ActionType act_type, Constraint::ActionEvent act_id);
 
 		//! \brief Returns the deferral tyep for the created foreign key (only for 1-1, 1-n relationships)
 		DeferralType getDeferralType();
 
+		//! \brief Defines the FK index access method (indexing type)
+		void setFKIndexType(IndexingType idx_type);
+
+		//! \brief Returns the FK index access method (indexing type)
+		IndexingType getFKIndexType();
+
 		//! \brief Defines if the relationship is identifier
 		void setIdentifier(bool value);
 
@@ -521,6 +557,8 @@ class __libcore Relationship: public BaseRelationship {
 		//! \brief Returns true when the receiver table is mandatory in the relationship
 		bool isReceiverTableMandatory();
 
+		virtual void setSQLDisabled(bool value) override;
+
 		friend class DatabaseModel;
 		friend class ModelWidget;
 		friend class RelationshipWidget;
