@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +20,6 @@
 */
 
 #include "table.h"
-#include "coreutilsns.h"
 
 Table::Table() : PhysicalTable()
 {
@@ -352,9 +354,9 @@ bool Table::isReferTableOnForeignKey(Table *ref_tab)
 	return found;
 }
 
-QString Table::__getSourceCode(SchemaParser::CodeType def_type, bool incl_rel_added_objs)
+QString Table::__getSourceCode(SchemaParser::CodeType def_type, bool incl_rel_added_objs, bool incl_constraints)
 {
-	setTableAttributes(def_type, incl_rel_added_objs);
+	setTableAttributes(def_type, incl_rel_added_objs, incl_constraints);
 
 	attributes[Attributes::Oids]=(with_oid ? Attributes::True : "");
 	attributes[Attributes::Unlogged]=(unlogged ? Attributes::True : "");
@@ -368,16 +370,16 @@ QString Table::__getSourceCode(SchemaParser::CodeType def_type, bool incl_rel_ad
 	return BaseObject::__getSourceCode(def_type);
 }
 
-QString Table::getDataDictionary(bool split, const attribs_map &extra_attribs)
+QString Table::getDataDictionary(bool split, bool md_format, const attribs_map &extra_attribs)
 {
 	try
 	{
 		attribs_map attribs = extra_attribs;
 
 		for(auto &obj : indexes)
-			attribs[Attributes::Indexes] +=  dynamic_cast<Index *>(obj)->getDataDictionary();
+			attribs[Attributes::Indexes] +=  dynamic_cast<Index *>(obj)->getDataDictionary(md_format);
 
-		return PhysicalTable::getDataDictionary(split, attribs);
+		return PhysicalTable::getDataDictionary(split, md_format, attribs);
 	}
 	catch(Exception &e)
 	{
@@ -385,12 +387,17 @@ QString Table::getDataDictionary(bool split, const attribs_map &extra_attribs)
 	}
 }
 
+void Table::updateDependencies()
+{
+	BaseTable::updateDependencies({});
+}
+
 QString Table::getSourceCode(SchemaParser::CodeType def_type)
 {
 	QString code_def=getCachedCode(def_type, false);
 	if(!code_def.isEmpty()) return code_def;
 
-	return __getSourceCode(def_type, false);
+	return __getSourceCode(def_type, false, true);
 }
 
 void Table::operator = (Table &tab)
@@ -404,42 +411,6 @@ void Table::operator = (Table &tab)
 	this->rls_enabled=tab.rls_enabled;
 }
 
-void Table::getColumnReferences(Column *column, std::vector<TableObject *> &refs, bool exclusion_mode)
-{
-	if(column && !column->isAddedByRelationship())
-	{
-		unsigned count, i;
-		IndexElement elem;
-		Column *col=nullptr;
-		std::vector<TableObject *>::iterator itr, itr_end;
-		bool found=false;
-		Index *ind=nullptr;
-
-		itr=indexes.begin();
-		itr_end=indexes.end();
-
-		while(itr!=itr_end && (!exclusion_mode || (exclusion_mode && !found)))
-		{
-			ind=dynamic_cast<Index *>(*itr);
-			itr++;
-
-			count=ind->getIndexElementCount();
-			for(i=0; i < count  && (!exclusion_mode || (exclusion_mode && !found)); i++)
-			{
-				elem=ind->getIndexElement(i);
-				col=elem.getColumn();
-				if(col && col==column)
-				{
-					found=true;
-					refs.push_back(ind);
-				}
-			}
-		}
-
-		PhysicalTable::getColumnReferences(column, refs, exclusion_mode);
-	}
-}
-
 QString Table::getTruncateDefinition(bool cascade)
 {
 	try
