@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -492,7 +495,13 @@ void Trigger::validateTrigger()
 	}
 }
 
-QString Trigger::getDataDictionary(const attribs_map &extra_attribs)
+bool Trigger::acceptsReplaceCommand()
+{
+	// Constraint triggers don't accept CREATE OR REPLACE command
+	return !is_constraint;
+}
+
+QString Trigger::getDataDictionary(bool md_format, const attribs_map &extra_attribs)
 {
 	try
 	{
@@ -533,8 +542,7 @@ QString Trigger::getDataDictionary(const attribs_map &extra_attribs)
 		attribs[Attributes::Events] = aux_list.join(", ");
 
 		schparser.ignoreEmptyAttributes(true);
-		return schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
-																																					 BaseObject::getSchemaName(ObjectType::Trigger)), attribs);
+		return schparser.getSourceCode(GlobalAttributes::getDictSchemaFilePath(md_format, getSchemaName()), attribs);
 	}
 	catch(Exception &e)
 	{
