@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,16 +28,15 @@
 #ifndef AGGREGATE_WIDGET_H
 #define AGGREGATE_WIDGET_H
 
-#include <QtWidgets>
 #include "baseobjectwidget.h"
 #include "ui_aggregatewidget.h"
 #include "pgsqltypewidget.h"
-#include "widgets/objectstablewidget.h"
+#include "widgets/customtablewidget.h"
 
 class __libgui AggregateWidget: public BaseObjectWidget, public Ui::AggregateWidget {
-	private:
-		Q_OBJECT
-		
+	Q_OBJECT
+
+	private:	
 		//! \brief Function input data type widget
 		PgSQLTypeWidget *input_type,
 		
@@ -44,7 +46,7 @@ class __libgui AggregateWidget: public BaseObjectWidget, public Ui::AggregateWid
 		/*! \brief Table that stores the multiple input data types. The elements
 		in this table are converted to class PgSQLType and assigned as input types
 		to the aggregat */
-		ObjectsTableWidget *input_types_tab;
+		CustomTableWidget *input_types_tab;
 		
 		//! \brief Syntax highlighter used by the initial condition field
 		SyntaxHighlighter *initial_cond_hl;
