@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,17 +30,17 @@
 
 #include "baseobjectwidget.h"
 #include "ui_rolewidget.h"
-#include "widgets/objectstablewidget.h"
+#include "widgets/customtablewidget.h"
 
 class __libgui RoleWidget: public BaseObjectWidget, public Ui::RoleWidget {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
+	private:
 		//! \brief Widget used to select roles on the database model
 		ModelObjectsWidget *object_selection_wgt;
 
 		//! \brief Store the table widgets used to reference the member roles
-		ObjectsTableWidget *members_tab[3];
+		CustomTableWidget *members_tab[3];
 
 		//! \brief Fills the tables with to member roles of the editing role
 		void fillMembersTable();
