@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,8 +32,7 @@
 #include "baseobjectwidget.h"
 
 class __libgui TextboxWidget: public BaseObjectWidget, public Ui::TextboxWidget {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
 	public:
 		TextboxWidget(QWidget * parent = nullptr);
