@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,12 +31,12 @@
 #include "baseobjectwidget.h"
 #include "ui_typewidget.h"
 #include "pgsqltypewidget.h"
-#include "widgets/objectstablewidget.h"
+#include "widgets/customtablewidget.h"
 
 class __libgui TypeWidget: public BaseObjectWidget, public Ui::TypeWidget {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
+	private:
 		//! \brief Type functions selectors widgets
 		ObjectSelectorWidget *functions_sel[9],
 
@@ -46,7 +49,7 @@ class __libgui TypeWidget: public BaseObjectWidget, public Ui::TypeWidget {
 		*range_subtype;
 
 		//! \brief Tables that store enumaration elementas and composite attributes
-		ObjectsTableWidget *enumerations_tab,
+		CustomTableWidget *enumerations_tab,
 		*attributes_tab;
 
 		//! \brief Composite type attribute collation selector
