@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +28,11 @@
 #ifndef MAIN_WINDOW_H
 #define MAIN_WINDOW_H
 
+#ifdef PRIVATE_PLUGINS_SYMBOLS
+	#include "privcoreinit.h"
+	#include "privcoreclasses.h"
+#endif
+
 #include <QMainWindow>
 #include <QPrintDialog>
 #include "ui_mainwindow.h"
@@ -168,9 +176,6 @@ class __libgui MainWindow: public QMainWindow, public Ui::MainWindow {
 
 		void resizeEvent(QResizeEvent *) override;
 
-		//! \brief Set the postion of a floating widget based upon an action at a tool bar
-		void setFloatingWidgetPos(QWidget *widget, QAction *act, QToolBar *toolbar, bool map_to_window);
-
 		void setBottomFloatingWidgetPos(QWidget *widget, QToolButton *btn);
 
 		void configureSamplesMenu();
@@ -205,10 +210,17 @@ class __libgui MainWindow: public QMainWindow, public Ui::MainWindow {
 
 		void dropEvent(QDropEvent *event) override;
 
+		void showEvent(QShowEvent *event) override;
+
 		/*! \brief Tries to restore the default configuration files and restart pgModeler
 		 *  in case of any configuration file is broken or missing */
 		void handleInitializationFailure(Exception &e);
 
+		/*! \brief Start the timers related to update check, model restoration and others
+		 *  This method works only on its first call. Any attempt to call it again will
+		 *  do nothing. The timers will be already running */
+		void startOtherTimers();
+
 public:
 		enum MWViewsId {
 			WelcomeView,
@@ -282,6 +294,9 @@ public:
 		//! \brief Shows a error dialog informing that the model demands a fix after the error ocurred when loading the filename.
 		void showFixMessage(Exception &e, const QString &filename);
 
+		//! \brief Set the postion of a floating widget based upon an action at a tool bar
+		void setFloatingWidgetPos(QWidget *widget, QAction *act, QToolBar *toolbar, bool map_to_window);
+
 	private slots:
 		void showMainMenu();
 
