@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,16 +31,14 @@
 #define BASE_CONF_WIDGET_H
 
 #include "guiglobal.h"
-#include "exception.h"
 #include "xmlparser.h"
-#include "attributes.h"
-#include <algorithm>
+#include "schemaparser.h"
 #include <QWidget>
 
 class __libgui BaseConfigWidget: public QWidget {
-	private:
-		Q_OBJECT
-		
+	Q_OBJECT
+
+	private:	
 		bool config_changed;
 		
 	protected:
@@ -69,11 +70,13 @@ class __libgui BaseConfigWidget: public QWidget {
 		 * If incl_elem_name = false then the resulting attribs map would contain only 2 elements for font and objects,
 		 * because we have two elements identified by "obj1" and "obj2". Now, when incl_elem_name=true the resulting attribs map
 		 * would contain four elements which keys are font-obj1, font-obj2, object-obj1, object-obj2. */
-		void loadConfiguration(const QString &filename, const QString &dtd, std::map<QString, attribs_map> &config_params, const QStringList &key_attribs = {}, bool incl_elem_name = false);
+		void loadConfiguration(const QString &filename, const QString &dtd, std::map<QString, attribs_map> &config_params,
+													 const QStringList &key_attribs = {}, bool incl_elem_name = false);
 
 		/*! \brief This is a convinience method that takes only the configuration file id instead of the filename and the DTD root element name.
 		 *  The conf_id is used to identify both the config file and its related DTD file. */
-		void loadConfiguration(const QString &conf_id, std::map<QString, attribs_map> &config_params, const QStringList &key_attribs={}, bool incl_elem_name = false);
+		void loadConfiguration(const QString &conf_id, std::map<QString, attribs_map> &config_params,
+													 const QStringList &key_attribs={}, bool incl_elem_name = false);
 		
 		//! \brief Get a configuratoin key from the xml parser
 		void getConfigurationParams(std::map<QString, attribs_map> &config_params, const QStringList &key_attribs = {}, bool incl_elem_name = false);
@@ -82,14 +85,17 @@ class __libgui BaseConfigWidget: public QWidget {
 		 * The silent parameter indicates that the restoration should not emit a message box informing the restoration sucess */
 		void restoreDefaults(const QString &conf_id, bool silent);
 		
-		//! \brief Adds a parameter to the specified configuration parameters set
-		static void addConfigurationParam(std::map<QString, attribs_map> &config_params, const QString &param, const attribs_map &attribs);
+		//! \brief Set the configuration parameters to a configuration section
+		static void setConfigurationSection(std::map<QString, attribs_map> &config_params, const QString &section_id, const attribs_map &params);
 		
-		void showEvent(QShowEvent *);
+		//! \brief Appends/overwrites the configuration parameters of the provided section_id.
+		static void appendConfigurationSection(std::map<QString, attribs_map> &config_params, const QString &section_id, const attribs_map &params);
+
+		virtual void showEvent(QShowEvent *) override;
 
 	public:
 		BaseConfigWidget(QWidget *parent = nullptr);
-		~BaseConfigWidget(void){}
+		~BaseConfigWidget(){}
 		
 		bool isConfigurationChanged();
 		
@@ -106,7 +112,7 @@ class __libgui BaseConfigWidget: public QWidget {
 		virtual void restoreDefaults(void)=0;
 		
 	public slots:
-		void setConfigurationChanged(bool changed=true);
+		virtual void setConfigurationChanged(bool changed = true);
 };
 
 #endif
