@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,11 +33,13 @@
 #include "objectsdiffinfo.h"
 
 class __libgui ModelsDiffHelper: public QObject {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
+	private:
 		//! \brief List of attributes ignored when comparing XML code of table children objects
-		static const QStringList TableObjsIgnoredAttribs,
+		static const QStringList
+
+		TableObjsIgnoredAttribs,
 
 		//! \brief List of tags ignored when comparing XML code of roles specifically
 		RolesIgnoredTags,
@@ -75,6 +80,10 @@ class __libgui ModelsDiffHelper: public QObject {
 		//! \brief Stores all objects filtered by the partial diff filters
 		std::map<unsigned, BaseObject *> filtered_objs;
 
+		/*! \brief Stores all objects types that are forced to be recreated
+		 *  by the option OptForceRecreation */
+		std::vector<ObjectType> forced_recreate_types;
+
 		/*! note The parameter diff_type in any methods below is one of the values in
 		ObjectsDiffInfo::CreateObject|AlterObject|DropObject */
 
@@ -126,12 +135,12 @@ class __libgui ModelsDiffHelper: public QObject {
 			//! \brief Indicates if any DROP/TRUNCATE generated must be in cascade mode
 			OptCascadeMode,
 
-			//! \brief Forces the recreation of any object maked as ALTER in the output
-			OptForceRecreation,
-
 			//! \brief Recreates only objects that can't be modified using ALTER commands
 			OptRecreateUnmodifiable,
 
+			//! \brief Recreates/replace the objects that can't be modified using ALTER commands but accepts CREATE OR REPLACE
+			OptReplaceModified,
+
 			//! \brief Indicates if permissions must be preserved on database
 			OptKeepObjectPerms,
 
@@ -180,6 +189,14 @@ class __libgui ModelsDiffHelper: public QObject {
 		//! \brief Toggles a diff option throught the OPT_xxx constants
 		void setDiffOption(DiffOptions opt_id, bool value);
 
+		/*! \brief Defines the object types that must be recreated forcebly.
+		 *  These object types are only used when OptForceRecreation option is set */
+		void setForcedRecreateTypes(const std::vector<ObjectType> &forced_rec_types);
+		void setForcedRecreateTypeNames(const QStringList &forced_rec_types);
+
+		//! \brief Returns if the provided type is one of the forced recreation ones
+		bool isForcedRecreateType(ObjectType obj_type);
+
 		//! \brief Configures the PostgreSQL version used in the diff generation
 		void setPgSQLVersion(const QString pgsql_ver);
 
