@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,14 +29,12 @@
 #define DONATE_WIDGET_H
 
 #include "guiglobal.h"
-#include <QWidget>
-#include <QGraphicsDropShadowEffect>
 #include "ui_donatewidget.h"
+#include <QGraphicsDropShadowEffect>
 
 class __libgui DonateWidget: public QWidget, public Ui::DonateWidget {
-	private:
-		Q_OBJECT
-		
+	Q_OBJECT
+
 	public:
 		DonateWidget(QWidget *parent = nullptr);
 		
