@@ -1,7 +1,10 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# (c) Copyright 2006-2026 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+#
+# DEVELOPMENT, MAINTENANCE AND COMMERCIAL DISTRIBUTION BY:
+# Nullptr Labs Software e Tecnologia LTDA <contact@nullptrlabs.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,8 +25,7 @@
 #include <QDialog>
 
 class LineNumbersTest: public QObject {
-  private:
-    Q_OBJECT
+	Q_OBJECT
 
   private slots:
 		void handleLineSelectionUsingMouse();
@@ -32,10 +34,11 @@ class LineNumbersTest: public QObject {
 void LineNumbersTest::handleLineSelectionUsingMouse()
 {
   QDialog *dlg=new QDialog;
-	NumberedTextEditor *edt=new NumberedTextEditor(dlg);
+	NumberedTextEditor *edt=new NumberedTextEditor(dlg, true);
   QHBoxLayout *layout=new QHBoxLayout(dlg);
 
 	LineNumbersWidget::setColors(Qt::darkGray, QColor(230,230,230));
+
   layout->addWidget(edt);
 	dlg->setMinimumSize(800,600);
 
@@ -85,9 +88,18 @@ SET standard_conforming_strings = on; \
 SET check_function_bodies = false; \
 SET client_min_messages = warning; \n\
 foobaar\n\
-bla\n");
+bla\n\
+-- Dumped from database version 9.4.4 -- Dumped by pg_dump version 9.4.4\
+ -- Started on 2015-07-20 19:24:52 WEST SET statement_timeout = 0; \
+SET lock_timeout = 0; SET client_encoding = 'UTF8'; \
+SET standard_conforming_strings = on; SET check_function_bodies = false; \
+SET client_min_messages = warning; -- Dumped from database version 9.4.4 \
+-- Dumped by pg_dump version 9.4.4 -- Started on 2015-07-20 19:24:52 WEST \
+SET statement_timeout = 0; SET lock_timeout = 0; SET client_encoding = 'UTF8'; \
+SET standard_conforming_strings = on; SET check_function_bodies = false; \
+SET client_min_messages = warning;\n\n\n\n\n\n\n");
 
-	edt->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
+	//edt->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
   dlg->exec();
 }
 
